@@ -74,6 +74,7 @@ Preferences::Preferences()
 
     //Plugins
     GraphPluginURL=__T("");
+    GraphPlugin64URL=__T("");
     GraphPluginVersion=__T("");
     FFmpegPluginURL=__T("");
     FFmpegPluginVersion=__T("");
@@ -219,6 +220,9 @@ int Preferences::Config_Load()
         SponsorUrl.Write(Saved);
     }
 
+    if (!Config(__T("GraphPlugin64URL")).empty())
+        GraphPlugin64URL=Config(__T("GraphPlugin64URL"));
+
     if (!Config(__T("GraphPluginURL")).empty())
         GraphPluginURL=Config(__T("GraphPluginURL"));
 
@@ -542,6 +546,13 @@ void __fastcall ThreadInternetCheck::Execute()
     Prefs->Config_Save();
 
     //Plugins
+    Ztring GraphPlugin64URL=Download(__T("GraphPlugin64URL"));
+    if (!GraphPlugin64URL.empty())
+    {
+        Prefs->Config(__T("GraphPlugin64URL"))=GraphPlugin64URL;
+        Prefs->Config_Save();
+    }
+
     Ztring GraphPluginURL=Download(__T("GraphPluginURL"));
     if (!GraphPluginURL.empty())
     {
