@@ -24,9 +24,19 @@
 #include <Menus.hpp>
 #include <StdCtrls.hpp>
 #include <Dialogs.hpp>
-#include "SHDocVw_OCX.h"
 #include <ExtCtrls.hpp>
 #include <Buttons.hpp>
+#include <System.ImageList.hpp>
+#include <System.IOUtils.hpp>
+#include <Vcl.BaseImageCollection.hpp>
+#include <Vcl.ImageCollection.hpp>
+#include <Vcl.VirtualImageList.hpp>
+#include <Registry.hpp>
+#include <Vcl.AppEvnts.hpp>
+#include <Vcl.Edge.hpp>
+#include <Winapi.ActiveX.hpp>
+#include <Winapi.WebView2.hpp>
+#include <SHDocVw.hpp>
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
@@ -84,10 +94,8 @@ __published:    // IDE-managed Components
     TTabSheet *Page_Text;
     TMemo *Page_Text_Text;
     TTabSheet *Page_HTML;
-    TCppWebBrowser *Page_HTML_HTML;
     TTabSheet *Page_Custom;
     TMemo *Page_Custom_Text;
-    TCppWebBrowser *Page_Custom_HTML;
     TTabSheet *Page_System;
     TGroupBox *Page_System_Buttons;
     TRadioButton *Page_System_Buttons_Video;
@@ -141,8 +149,6 @@ __published:    // IDE-managed Components
     TMenuItem *M_Help_SupportedParameters;
     TMenuItem *M_Language;
     TMenuItem *ToDo1;
-    TImageList *Menu_Image;
-    TImageList *ToolBar_Image;
     TPopupMenu *ToolBar_View_Menu;
     TMenuItem *ToolBar_View_Easy;
     TMenuItem *ToolBar_View_Sheet;
@@ -152,7 +158,6 @@ __published:    // IDE-managed Components
     TMenuItem *ToolBar_View_Custom;
     TMenuItem *N3;
     TMenuItem *ToolBar_View_System;
-    TImageList *ToolBar_Image_Disabled;
     TMenuItem *M_Options_ShowMenu;
     TMenuItem *N4;
     TMenuItem *ToolBar_View_ShowMenu;
@@ -163,23 +168,11 @@ __published:    // IDE-managed Components
     TLabel *Page_Easy_T3_Codec;
     TButton *Page_Easy_T3_Web;
     TMenuItem *M_Debug_Avanced_More;
-    TOpenDialog *OpenDialog1;
     TMenuItem *M_Debug_Details0;
     TMenuItem *N7;
     TMenuItem *M_Debug_Details50;
     TMenuItem *M_Debug_Details90;
     TMenuItem *M_Debug_Details100;
-    TSpeedButton *SpeedButton1;
-    TBitBtn *Donate_en;
-    TBitBtn *Donate_fr;
-    TButton *Donate___;
-    TBitBtn *Donate_de;
-    TBitBtn *Donate_es;
-    TBitBtn *Donate_it;
-    TBitBtn *Donate_ja;
-    TBitBtn *Donate_pl;
-    TBitBtn *Donate_zh_CN;
-    TBitBtn *Donate_zh_TW;
     TMenuItem *M_NewVersion;
     TMenuItem *M_View_XML;
     TMenuItem *M_View_JSON;
@@ -220,6 +213,22 @@ __published:    // IDE-managed Components
     TMenuItem *ToolBar_View_reVTMD;
     TMenuItem *ToolBar_View_NISO_Z39_87;
     TMenuItem *ToolBar_View_Graph_Svg;
+    TImageCollection *ImageCollection1;
+    TVirtualImageList *Menu_Image;
+    TVirtualImageList *ToolBar_Image;
+    TVirtualImageList *ToolBar_Image_Disabled;
+    TFileOpenDialog *FileOpenDialog1;
+    TFileOpenDialog *FolderOpenDialog1;
+    TApplicationEvents *ApplicationEvents1;
+    TPanel *Page_Sheet_Panel1;
+    TSplitter *Page_Sheet_Splitter1;
+    TPanel *Page_Sheet_Panel2;
+    TMenuItem *M_Options_Theme;
+    TMenuItem *M_Options_Theme_System;
+    TMenuItem *M_Options_Theme_Light;
+    TMenuItem *M_Options_Theme_Dark;
+    TWebBrowser *Page_HTML_HTML;
+    TWebBrowser *Page_Custom_HTML;
     void __fastcall FormResize(TObject *Sender);
     void __fastcall M_Help_AboutClick(TObject *Sender);
     void __fastcall M_Options_PreferencesClick(TObject *Sender);
@@ -251,27 +260,18 @@ __published:    // IDE-managed Components
     void __fastcall M_LanguageClick(TObject *Sender);
     void __fastcall M_Help_SupportedParametersClick(TObject *Sender);
     void __fastcall M_File_ExportClick(TObject *Sender);
-    void __fastcall Page_Sheet_SheetSelectCell(TObject *Sender, int ACol, int ARow,
-          bool &CanSelect);
+    void __fastcall Page_Sheet_SheetSelectCell(TObject *Sender, System::LongInt ACol,
+          System::LongInt ARow, bool &CanSelect);
     void __fastcall Page_Easy_FileChange(TObject *Sender);
     void __fastcall Page_Easy_DifferentViewClick(TObject *Sender);
     void __fastcall FormClose(TObject *Sender, TCloseAction &Action);
+    void __fastcall FormDestroy(TObject *Sender);
     void __fastcall Page_Sheet_Change(TObject *Sender);
     void __fastcall Page_Sheet_WebClick(TObject *Sender);
     void __fastcall Page_Easy_WebClick(TObject *Sender);
     void __fastcall M_Options_ShowMenuClick(TObject *Sender);
     void __fastcall M_Debug_Dummy_MovieClick(TObject *Sender);
     void __fastcall M_Debug_DummyClick(TObject *Sender);
-    void __fastcall Donate_enClick(TObject *Sender);
-    void __fastcall Donate_deClick(TObject *Sender);
-    void __fastcall Donate_esClick(TObject *Sender);
-    void __fastcall Donate_frClick(TObject *Sender);
-    void __fastcall Donate_itClick(TObject *Sender);
-    void __fastcall Donate_jaClick(TObject *Sender);
-    void __fastcall Donate_plClick(TObject *Sender);
-    void __fastcall Donate_zh_CNClick(TObject *Sender);
-    void __fastcall Donate_zh_TWClick(TObject *Sender);
-    void __fastcall Donate___Click(TObject *Sender);
     void __fastcall M_NewVersionClick(TObject *Sender);
     void __fastcall M_View_MPEG7_StrictClick(TObject *Sender);
     void __fastcall M_View_MPEG7_RelaxedClick(TObject *Sender);
@@ -294,8 +294,22 @@ __published:    // IDE-managed Components
     void __fastcall M_View_NISO_Z39_87Click(TObject *Sender);
     void __fastcall M_View_Graph_SvgClick(TObject *Sender);
     void __fastcall M_Options_FullParsingClick(TObject *Sender);
+    void __fastcall ApplicationEvents1OnSettingChange(TObject *Sender, int Flag, const UnicodeString Section,
+          System::LongInt &Result);
+    void __fastcall Page_Sheet_Splitter1Moved(TObject *Sender);
+    void __fastcall M_Options_Theme_SystemClick(TObject *Sender);
+    void __fastcall M_Options_Theme_LightClick(TObject *Sender);
+    void __fastcall M_Options_Theme_DarkClick(TObject *Sender);
+protected:
+    virtual void __fastcall CreateWnd();
+    virtual void __fastcall DestroyWnd();
 private:    // User declarations
     TButton *Footer_Button;
+    const UnicodeString LIGHT_MODE_STYLE = "Windows";               // Name of style for light mode;
+    const UnicodeString DARK_MODE_STYLE = "Windows11 Modern Dark";  // Name of style for dark mode
+    bool __fastcall WindowsDarkModeEnabled();
+    void __fastcall ConfigTheme();
+    std::wstring __fastcall InjectHTMLStyle(const wchar_t* HTMLDocument);
 public:        // User declarations
     MESSAGE void __fastcall HandleDropFiles (TMessage&);
     BEGIN_MESSAGE_MAP
