@@ -436,21 +436,24 @@ void __fastcall TPreferencesF::Advanced_InformTimestampClick(TObject *Sender)
 //---------------------------------------------------------------------------
 void __fastcall TPreferencesF::Advanced_EnableFfmpegClick(TObject *Sender)
 {
-    if (Advanced_EnableFfmpeg->Checked && Prefs->Config(__T("EnableFfmpeg"), 1) != __T("1"))
+    if (Advanced_EnableFfmpeg->Checked)
     {
         #ifndef MEDIAINFOGUI_PLUGIN_NO
-        Ztring InstallFolder = Application->ExeName.c_str();
-        InstallFolder = InstallFolder.substr(0, InstallFolder.rfind(__T("\\")) + 1);
-
-        if (!File::Exists(InstallFolder+__T("\\Plugin\\FFmpeg\\version.txt"))) //Try to install plugin
+        if (Prefs->Config(__T("EnableFfmpeg"), 1) != __T("1"))
         {
-            TPluginF* P = new TPluginF(this, PLUGIN_FFMPEG);
-            if (P->Configure())
-                P->ShowModal();
-            delete P;
+            Ztring InstallFolder = Application->ExeName.c_str();
+            InstallFolder = InstallFolder.substr(0, InstallFolder.rfind(__T("\\")) + 1);
 
-            if (!File::Exists(InstallFolder+__T("\\Plugin\\FFmpeg\\version.txt")))
-                MessageBox(NULL, __T("An error occured, please download and install the plugin manually from the MediaInfo download page."), __T("Error"), MB_OK);
+            if (!File::Exists(InstallFolder+__T("\\Plugin\\FFmpeg\\version.txt"))) //Try to install plugin
+            {
+                TPluginF* P = new TPluginF(this, PLUGIN_FFMPEG);
+                if (P->Configure())
+                    P->ShowModal();
+                delete P;
+
+                if (!File::Exists(InstallFolder+__T("\\Plugin\\FFmpeg\\version.txt")))
+                    MessageBox(NULL, __T("An error occured, please download and install the plugin manually from the MediaInfo download page."), __T("Error"), MB_OK);
+            }
         }
         #endif
         Prefs->Config(__T("EnableFfmpeg"), 1)=__T("1");
@@ -461,6 +464,17 @@ void __fastcall TPreferencesF::Advanced_EnableFfmpegClick(TObject *Sender)
     }
 }
 
+//---------------------------------------------------------------------------
+void __fastcall TPreferencesF::Advanced_DisplayCaptions_SelChange(TObject *Sender)
+{
+    if (Advanced_DisplayCaptions_Sel->ItemIndex==0)
+        Prefs->Config(__T("DisplayCaptions"))=__T("Content");
+    else if (Advanced_DisplayCaptions_Sel->ItemIndex==1)
+        Prefs->Config(__T("DisplayCaptions"))=__T("Command");
+    else if (Advanced_DisplayCaptions_Sel->ItemIndex==2)
+        Prefs->Config(__T("DisplayCaptions"))=__T("Stream");
+}
+
 //---------------------------------------------------------------------------
 void __fastcall TPreferencesF::Language_NewClick(TObject *Sender)
 {
@@ -567,7 +581,7 @@ void __fastcall TPreferencesF::TreeChange(TObject *Sender,
 //---------------------------------------------------------------------------
 void __fastcall TPreferencesF::General_Language_MoreClick(TObject *Sender)
 {
-    Tree->Select(Tree->Items->Item[6]);
+    Tree->Select(Tree->Items->Item[7]);
 }
 
 //---------------------------------------------------------------------------
@@ -592,11 +606,17 @@ void __fastcall TPreferencesF::FormShow(TObject *Sender)
     General_Output_SelChange(NULL);
 
     //Not done with BCB because I want to easy select tabs in it
-    Page->Top=-6;
-    Page->TabHeight=1;
-    Cancel->Top=Page->Top+Page->Height;
+    //Page->Top=-6;
+    //Page->TabHeight=1;
+    Page->Top=-(Page->TabHeight*1.15);                //Replaced above with this to hide tabs better on high-DPI
+    Page->Height=Page->Height+(Page->TabHeight*1.15); //Required with above line
+    Cancel->Top=Page->Top+Page->Height+(Cancel->Height*0.15);
     OK->Top=Cancel->Top;
-    ClientHeight=OK->Top+OK->Height;
+    ClientHeight=OK->Top+(OK->Height*1.15);
+
+    //Make them same size after DPI scaling
+    General_Language_More->Height=General_Language_Sel->Height;
+    General_Output_More->Height=General_Output_Sel->Height;
 }
 
 //---------------------------------------------------------------------------
@@ -618,6 +638,14 @@ void __fastcall TPreferencesF::Setup_AdvancedShow(TObject *Sender)
     Advanced_InformVersion->Checked=Prefs->Config(__T("InformVersion")).To_int32s();
     Advanced_InformTimestamp->Checked=Prefs->Config(__T("InformTimestamp")).To_int32s();
     Advanced_EnableFfmpeg->Checked=Prefs->Config(__T("EnableFfmpeg")).To_int32s();
+
+    //Display captions
+    if (Prefs->Config(__T("DisplayCaptions"))==__T("Content"))
+        Advanced_DisplayCaptions_Sel->ItemIndex=0;
+    else if (Prefs->Config(__T("DisplayCaptions"))==__T("Stream"))
+        Advanced_DisplayCaptions_Sel->ItemIndex=2;
+    else // Command (default)
+        Advanced_DisplayCaptions_Sel->ItemIndex=1;
 }
 
 //---------------------------------------------------------------------------
@@ -733,6 +761,11 @@ void __fastcall TPreferencesF::GUI_Configure()
     Advanced_InformVersion->Caption=Prefs->Translate(__T("Add version to text output")).c_str();
     Advanced_InformTimestamp->Caption=Prefs->Translate(__T("Add creation date to text output")).c_str();
     Advanced_EnableFfmpeg->Caption=Prefs->Translate(__T("Enable FFmpeg plugin")).c_str();
+    Advanced_DisplayCaptions_Caption->Caption=Prefs->Translate(__T("DisplayCaptions")).c_str();
+    Advanced_DisplayCaptions_Sel->Items->Clear();
+    Advanced_DisplayCaptions_Sel->Items->Add(Prefs->Translate(__T("DisplayCaptions_Content")).c_str());
+    Advanced_DisplayCaptions_Sel->Items->Add(Prefs->Translate(__T("DisplayCaptions_Command")).c_str());
+    Advanced_DisplayCaptions_Sel->Items->Add(Prefs->Translate(__T("DisplayCaptions_Stream")).c_str());
     //-Language
     Language_Caption->Caption=Prefs->Translate(__T("Choose language")).c_str();
     Language_Edit->Caption=(Prefs->Translate(__T("Edit"))+__T("...")).c_str();
